#' atable: Create Tables for Reporting Clinical Trials
#'
#'The packages provides functions for descriptive statistics and hypothesis tests, and arranging the results for printing.
#'
#' The main function is \code{\link{atable}}. See documentation there.
#'
#'
#' @keywords internal
"_PACKAGE"
NULL
